@@ -1,6 +1,8 @@
 
 #%%
 import pytest
+import numpy as np
+import datetime as dt
 from pandas import read_csv
 import pandas as pd
 import os
@@ -15,8 +17,8 @@ from pathlib import Path
 #     from project_path import module_path
 
 
-from sutra2.Analytical_Well import *
-from sutra2.Substance_Transport import *
+import sutra2.Analytical_Well as AW
+import sutra2.Transport_Removal as TR
 from pandas.testing import assert_frame_equal
 import warnings
 
@@ -30,7 +32,7 @@ def test_travel_time_distribution_phreatic():
     output_phreatic = pd.read_csv(path / 'phreatic_test.csv')
     output_phreatic = output_phreatic.round(7) #round to 7 digits (or any digit), keep same as for the output for the model to compare
 
-    test_ = HydroChemicalSchematisation(schematisation_type='phreatic',
+    test_ = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                         computation_method= 'analytical',
                                         what_to_export='omp', # @alex: what_to_export sounds very cryptic and ad-hoc. maybe we can think of something better
                                         well_discharge=-319.4*24,
@@ -55,7 +57,7 @@ def test_travel_time_distribution_phreatic():
                                         diameter_borehole = 0.75,
                                         )
 
-    well1 = AnalyticalWell(test_)
+    well1 = AW.AnalyticalWell(test_)
     well1.phreatic()
     output = well1.df_output
     output = output[["total_travel_time", "travel_time_unsaturated",
@@ -66,12 +68,12 @@ def test_travel_time_distribution_phreatic():
     assert_frame_equal(output, output_phreatic,check_dtype=False)
 
 
-def test_retardation_temp_koc_correction(substance = 'benzene', schematisation_type='phreatic'):
+def test_retardation_temp_koc_correction(pollutant = 'benzene', schematisation_type='phreatic'):
     """ Compares the calculated retardation coefficient for each redox zone against a known case from TRANSATOMIC excel """
-    test_ = HydroChemicalSchematisation(schematisation_type=schematisation_type,
+    test_ = AW.HydroChemicalSchematisation(schematisation_type=schematisation_type,
                                         computation_method= 'analytical',
                                         what_to_export='omp',
-                                        name = substance,
+                                        name = pollutant,
                                       well_discharge=-319.4*24,
                                       hor_permeability_shallow_aquifer = 0.02,
                                       porosity_vadose_zone=0.38,
@@ -104,12 +106,16 @@ def test_retardation_temp_koc_correction(substance = 'benzene', schematisation_t
                                       solid_density_target_aquifer= 2.650,
                                       diameter_borehole = 0.75,
                                     )
-    well1 = AnalyticalWell(test_)
+    well1 = AW.AnalyticalWell(test_)
     if schematisation_type=='phreatic':
         well1.phreatic()
     elif  schematisation_type=='semiconfined':
         well1.semiconfined()
-    conc1 = SubstanceTransport(well1, substance = substance) #, df_particle, df_flowline)
+
+    # substance object to retrieve removal parameters for
+    substance = TR.Substance(substance_name = pollutant)
+
+    conc1 = TR.Transport(well1, pollutant = substance) #, df_particle, df_flowline)
     conc1.compute_omp_removal()
 
     retardation = {
@@ -129,9 +135,9 @@ def test_retardation_temp_koc_correction(substance = 'benzene', schematisation_t
             'target_aquifer': 1.0000000004342615,
         },
     }
-    retardation_array = np.array([retardation[substance]['vadose_zone'],
-                    retardation[substance]['shallow_aquifer'],
-                    retardation[substance]['target_aquifer']])
+    retardation_array = np.array([retardation[pollutant]['vadose_zone'],
+                    retardation[pollutant]['shallow_aquifer'],
+                    retardation[pollutant]['target_aquifer']])
 
     test_array = np.array(conc1.df_particle.retardation.loc[1:3], dtype='float')
 
@@ -146,14 +152,14 @@ def test_retardation_temp_koc_correction(substance = 'benzene', schematisation_t
     else:
         print("Success, no error in retardation!")
 
-def test_steady_concentration_temp_koc_correction_phreatic(substance='benzene'):
+def test_steady_concentration_temp_koc_correction_phreatic(pollutant='benzene'):
     """ Compares the calculated steady state concentration for a specific radial distance
     for each redox zone against a known case from TRANSATOMIC excel """
 
-    test_ = HydroChemicalSchematisation(schematisation_type='phreatic',
+    test_ = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                         computation_method= 'analytical',
                                         what_to_export='omp',
-                                        name = substance,
+                                        name = pollutant,
                                       well_discharge=-319.4*24,
                                     #   vertical_resistance_shallow_aquifer=500,
                                       hor_permeability_shallow_aquifer = 0.02,
@@ -187,10 +193,13 @@ def test_steady_concentration_temp_koc_correction_phreatic(substance='benzene'):
                                       solid_density_target_aquifer= 2.650,
                                       diameter_borehole = 0.75,
                                     )
-    well1 = AnalyticalWell(test_)
+    well1 = AW.AnalyticalWell(test_)
     well1.phreatic()
-    # substance = 'benzene'
-    conc1 = SubstanceTransport(well1, substance = substance) #, df_particle, df_flowline)
+    # pollutant = 'benzene'
+    # substance object to retrieve removal parameters for
+    substance = TR.Substance(substance_name = pollutant)
+
+    conc1 = TR.Transport(well1, pollutant = substance) #, df_particle, df_flowline)
     conc1.compute_omp_removal()
 
     steady_state_concentration = {
@@ -210,9 +219,9 @@ def test_steady_concentration_temp_koc_correction_phreatic(substance='benzene'):
             'target_aquifer': 1.850450098e-10, #1.8504500983690007e-10,
         },
     }
-    concentration_array = np.array([steady_state_concentration[substance]['vadose_zone'],
-                    steady_state_concentration[substance]['shallow_aquifer'],
-                    steady_state_concentration[substance]['target_aquifer']])
+    concentration_array = np.array([steady_state_concentration[pollutant]['vadose_zone'],
+                    steady_state_concentration[pollutant]['shallow_aquifer'],
+                    steady_state_concentration[pollutant]['target_aquifer']])
 
     test_array = np.array(conc1.df_particle.steady_state_concentration.loc[1:3], dtype=float)
 
@@ -238,7 +247,7 @@ def test_travel_time_distribution_semiconfined():
     output_semiconfined = pd.read_csv(path / 'semiconfined_test_fixed_TTD.csv')
 
     output_semiconfined = output_semiconfined.round(7)
-    test_ = HydroChemicalSchematisation(schematisation_type='semiconfined',
+    test_ = AW.HydroChemicalSchematisation(schematisation_type='semiconfined',
                                         computation_method= 'analytical',
                                         what_to_export='omp',
                                         well_discharge=-319.4*24,
@@ -261,7 +270,7 @@ def test_travel_time_distribution_semiconfined():
                                         solid_density_shallow_aquifer= 2.650,
                                         solid_density_target_aquifer= 2.650,
                                         diameter_borehole = 0.75,)
-    well1 = AnalyticalWell(test_)
+    well1 = AW.AnalyticalWell(test_)
     well1.semiconfined()
     output = well1.df_output
     # output = output_dict['df_output']
@@ -280,13 +289,13 @@ def test_travel_time_distribution_semiconfined():
     #     print("Success, no error in TTD!")
 
 
-def test_steady_concentration_temp_koc_correction_semiconfined(substance='benzene'):
+def test_steady_concentration_temp_koc_correction_semiconfined(pollutant='benzene'):
     """ Compares the calculated retardation coefficient for each redox zone against a known case from TRANSATOMIC excel """
 
-    test_ = HydroChemicalSchematisation(schematisation_type='semiconfined',
+    test_ = AW.HydroChemicalSchematisation(schematisation_type='semiconfined',
                                         computation_method= 'analytical',
                                         what_to_export='omp',
-                                        name = substance,
+                                        name = pollutant,
                                       well_discharge=-319.4*24,
                                       hor_permeability_shallow_aquifer = 0.02,
                                       porosity_vadose_zone=0.38,
@@ -319,10 +328,13 @@ def test_steady_concentration_temp_koc_correction_semiconfined(substance='benzen
                                       solid_density_target_aquifer= 2.650,
                                       diameter_borehole = 0.75,
                                     )
-    well1 = AnalyticalWell(test_)
+    well1 = AW.AnalyticalWell(test_)
     well1.semiconfined()
-    # substance = 'benzene'
-    conc1 = SubstanceTransport(well1, substance = substance) #, df_particle, df_flowline)
+
+    # substance object to retrieve removal parameters for
+    substance = TR.Substance(substance_name = pollutant)
+
+    conc1 = TR.Transport(well1, pollutant = substance) #, df_particle, df_flowline)
     conc1.compute_omp_removal()
 
     steady_state_concentration = {
@@ -342,9 +354,9 @@ def test_steady_concentration_temp_koc_correction_semiconfined(substance='benzen
             'target_aquifer':0.008232593,
         },
     }
-    concentration_array = np.array([steady_state_concentration[substance]['vadose_zone'],
-                    steady_state_concentration[substance]['shallow_aquifer'],
-                    steady_state_concentration[substance]['target_aquifer']])
+    concentration_array = np.array([steady_state_concentration[pollutant]['vadose_zone'],
+                    steady_state_concentration[pollutant]['shallow_aquifer'],
+                    steady_state_concentration[pollutant]['target_aquifer']])
 
     test_array = np.array(conc1.df_particle.steady_state_concentration.loc[1:3], dtype=float)
 
@@ -366,7 +378,7 @@ def test_start_end_dates_contamination():
     ''' Tests whether the correct exception is raised when the 'end_date_contamiantion' is before 'start_date_contamination' '''
 
     with pytest.raises(ValueError) as exc:
-        phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+        phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                                     computation_method= 'analytical',
                                                     what_to_export='omp',
                                                     well_discharge=-319.4*24, #m3/day
@@ -381,7 +393,7 @@ def test_compute_for_date_start_dates_contamination():
     ''' Tests whether the correct exception is raised when the 'computer_contamiantion_for_date' is before 'start_date_contamination' '''
 
     with pytest.raises(ValueError) as exc:
-        phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+        phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                                     computation_method= 'analytical',
                                       what_to_export='omp',
                                       well_discharge=-319.4*24, #m3/day
@@ -398,7 +410,7 @@ def test_compute_for_date_start_date_well():
     'computer_contamiantion_for_date' is before 'start_date_contamination' '''
 
     with pytest.raises(ValueError) as exc:
-        phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+        phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                                     computation_method= 'analytical',
                                       what_to_export='omp',
                                       well_discharge=-319.4*24, #m3/day
@@ -416,7 +428,7 @@ def test_incorrect_date_input_format():
     'computer_contamiantion_for_date' is before 'start_date_contamination' '''
 
     with pytest.raises(TypeError) as exc:
-        phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+        phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                                     computation_method= 'analytical',
                                       what_to_export='omp',
                                       well_discharge=-319.4*24, #m3/day
@@ -430,7 +442,7 @@ def test_redox_options():
     ''' Tests whether the correct exception is raised when one of the redox zones
      is not one of'suboxic', 'anoxic', 'deeply_anoxic' '''
     with pytest.raises(ValueError) as exc:
-        phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+        phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                                     computation_method= 'analytical',
                                 what_to_export='omp',
                                 well_discharge=-319.4*24, #m3/day
@@ -447,7 +459,7 @@ def test_phreatic_diffuse_point_source():
     ''' Test for phreatic case with both a diffuse and point source contamination, 
     Checks if the concentration over time matches a known case'''
 
-    phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+    phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                       computation_method= 'analytical',
                                       removal_function = 'omp',
                                       what_to_export='omp',
@@ -494,9 +506,13 @@ def test_phreatic_diffuse_point_source():
                                       end_date_contamination=dt.datetime.strptime('1990-01-01',"%Y-%m-%d"),
 
                                       )
-    phreatic_well = AnalyticalWell(phreatic_scheme)
+    phreatic_well = AW.AnalyticalWell(phreatic_scheme)
     phreatic_well.phreatic()
-    phreatic_conc = SubstanceTransport(phreatic_well, substance = 'OMP-X')
+
+    # substance object to retrieve removal parameters for
+    substance = TR.Substance(substance_name = 'OMP-X')
+
+    phreatic_conc = TR.Transport(phreatic_well, pollutant = substance)
     phreatic_conc.compute_omp_removal()
     df_well_concentration = phreatic_conc.compute_concentration_in_well_at_date()
     df_well_concentration = df_well_concentration.astype({'time': 'int32', 'date': 'datetime64[ns]', 'total_concentration_in_well': 'float64'})
@@ -518,7 +534,7 @@ def test_phreatic_diffuse_only_source():
     ''' Test for phreatic case with only a diffuse source contamination
     Checks if the concentration over time matches a known case'''
 
-    phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+    phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                     computation_method= 'analytical',
                                     removal_function = 'omp',
                                     what_to_export='omp',
@@ -559,9 +575,13 @@ def test_phreatic_diffuse_only_source():
                                     compute_contamination_for_date=dt.datetime.strptime('2050-01-01',"%Y-%m-%d"),
                                     end_date_contamination=dt.datetime.strptime('1990-01-01',"%Y-%m-%d"),
                                     )
-    phreatic_well = AnalyticalWell(phreatic_scheme)
+    phreatic_well = AW.AnalyticalWell(phreatic_scheme)
     phreatic_well.phreatic()
-    phreatic_conc = SubstanceTransport(phreatic_well, substance = 'OMP-X')
+
+    # substance object to retrieve removal parameters for
+    substance = TR.Substance(substance_name = 'OMP-X')
+
+    phreatic_conc = TR.Transport(phreatic_well, pollutant = substance)
     phreatic_conc.compute_omp_removal()
     df_well_concentration = phreatic_conc.compute_concentration_in_well_at_date()
 
@@ -581,7 +601,7 @@ def test_phreatic_point_only_source():
     ''' Test for phreatic case with only a diffuse source contamination,
     Checks if the concentration over time matches a known case'''
 
-    phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+    phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                     computation_method= 'analytical',
                                     removal_function = 'omp',
                                     what_to_export='omp',
@@ -628,9 +648,13 @@ def test_phreatic_point_only_source():
                                     end_date_contamination=dt.datetime.strptime('1990-01-01', "%Y-%m-%d"),
 
                                     )
-    phreatic_well = AnalyticalWell(phreatic_scheme)
+    phreatic_well = AW.AnalyticalWell(phreatic_scheme)
     phreatic_well.phreatic()
-    phreatic_conc = SubstanceTransport(phreatic_well, substance = 'OMP-X')
+
+    # substance object to retrieve removal parameters for
+    substance = TR.Substance(substance_name='OMP-X')
+
+    phreatic_conc = TR.Transport(phreatic_well, pollutant = substance)
     phreatic_conc.compute_omp_removal()
     df_well_concentration = phreatic_conc.compute_concentration_in_well_at_date()
 
@@ -650,7 +674,7 @@ def test_drawdown_lower_than_target_aquifer():
     ''' Tests whether the correct exception is raised when the drawdown of the 
     well is lower than the bottom of the target aquifer' '''
     with pytest.raises(ValueError) as exc:
-        phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+        phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
                                         computation_method= 'analytical',
                                         what_to_export='omp', # @alex: what_to_export sounds very cryptic and ad-hoc. maybe we can think of something better
                                         well_discharge=-319.4*24,
@@ -663,7 +687,7 @@ def test_drawdown_lower_than_target_aquifer():
                                         moisture_content_vadose_zone=0.15,
                                         ground_surface = 22,)
 
-        phreatic_well = AnalyticalWell(phreatic_scheme)
+        phreatic_well = AW.AnalyticalWell(phreatic_scheme)
 
         phreatic_well.phreatic()                                         
     assert "The drawdown at the well is lower than the bottom of the target aquifer. Please select a different schematisation." in str(exc.value)
@@ -674,7 +698,7 @@ def test_drawdown_lower_than_target_aquifer():
 #     ''' Tests whether a warning is issued when the head drawdown reaches the target aquifer' '''
 #     @MartinK how to raise a warning here?
 #     with AnalyticalWell.assertWarns(Warning) as exc:
-#         phreatic_scheme = HydroChemicalSchematisation(schematisation_type='phreatic',
+#         phreatic_scheme = AW.HydroChemicalSchematisation(schematisation_type='phreatic',
 #                                         computation_method= 'analytical',
 #                                         what_to_export='omp', # @alex: what_to_export sounds very cryptic and ad-hoc. maybe we can think of something better
 #                                         well_discharge=-319.4*24,
